@@ -1,9 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from DebugLog import DebugLog
+from utils.DebugLog import DebugLog
 from PyQt4 import QtCore
-id=0
 
 class Ride:
    def __init__(self, train, heure, destination, voie):
