@@ -6,8 +6,7 @@ from PyQt4 import QtCore, QtGui
 from PyQt4.QtCore import QAbstractTableModel, Qt, QVariant
 from utils.DebugLog import DebugLog
 from utils.TrainDb import  DbTrain, GareManager
-import ConfigParser
-from utils.ConfFile import ConfFile, RidesConfig
+from utils.Config import TrainTrainConf, ConfFile, RidesConfig
 from extractors.ExtractorTransilien import ExtractorTransilien
 from extractors.ExtractorMetroMobi import ExtractorMetro
 from extractors.ExtractorRERratp import ExtractorRERratp
@@ -42,16 +41,15 @@ class TrainTrainModel(QAbstractTableModel):
       if not os.path.exists(confDir):
          os.makedirs(confDir)
 
-      self.confFile = os.path.join(confDir, "traintrain.conf")
       self.ridesConfFile = os.path.join(confDir, "trajets.conf")
 
       self.garesConf = RidesConfig(self.ridesConfFile)
-      self.arraydata = []
       self.rides = dict()
       self.db = DbTrain()
       self.gareMgr = GareManager(self.db)
       self.online = True
-      self.max = 2
+      t = TrainTrainConf()
+      self.max = t.nbTrains()
 
    def GetRidesModel(self):
       return [self.rides[k] for k in sorted(self.rides.keys())]
@@ -90,7 +88,7 @@ class TrainTrainModel(QAbstractTableModel):
          extractor = ExtractorRERratp(ligne)
 
       if extractor:
-         self.rideList.append(extractor)
+         self.rideList[extractor.id] = extractor
          self.AddRideModel( extractor.rideModel )
          self.connect(extractor, QtCore.SIGNAL('extracted'), self.Extracted, QtCore.Qt.QueuedConnection)
          extractor.SetOnline(self.online)
@@ -103,8 +101,7 @@ class TrainTrainModel(QAbstractTableModel):
       DebugLog("TrainTrainModel::InitDatas")
 
       self.garesConf.ReadRides()
-      self.rideList = []
-      self.arraydata = []
+      self.rideList = dict()
       self.reset()
 
       for ligne in self.garesConf.GetRides():
@@ -113,7 +110,10 @@ class TrainTrainModel(QAbstractTableModel):
    def Extracted(self, rideModel):
       self.emit(QtCore.SIGNAL('extracted'), rideModel)
 
-   def RefreshDatas(self):
+   def RefreshDatas(self, id=None):
       DebugLog("TrainTrainModel::RefreshDatas")
-      for extractor in self.rideList:
-         extractor.FetchDatas(self, self.max)
+      if id:
+         self.rideList[id].FetchDatas(self, self.max)
+      else:
+         for extractor in self.rideList.values():
+            extractor.FetchDatas(self, self.max)
