@@ -3,13 +3,16 @@
 
 from PyQt4 import QtCore
 import sys, sqlite3, os
-
+from DebugLog import getScriptPath
+   
 class DbTrain:
    def __init__(self):
-      if not os.path.exists('datas/tec.sqlite'):
-         raise RuntimeError("'datas/tec.sqlite' not found")
+      datas = os.path.join(os.path.dirname(getScriptPath()), 'datas/tec.sqlite')
+      
+      if not os.path.exists(datas):
+         raise RuntimeError("'%s' not found"%datas)
 
-      conn = sqlite3.connect('datas/tec.sqlite')
+      conn = sqlite3.connect(datas)
       self.c = conn.cursor()
 
    def execute(self, req):
