@@ -6,7 +6,7 @@ from PyQt4 import QtGui, QtCore
 from PyQt4.QtCore import Qt
 from utils.DebugLog import DebugLog, getScriptPath
 from model.RideModel import RideModel
-from utils.CircleProgress import CircleProgress
+from view.CircleProgress import CircleProgress
 
 class RideView(QtGui.QWidget):
    def __init__(self, model, parent):
@@ -128,7 +128,9 @@ class RideView(QtGui.QWidget):
       title.setFont(self.font)
       title.setStyleSheet("background: #fff; padding:10px; color: #194F97; text-align:left; border: none ")
       menu = QtGui.QMenu(title)
+      refreshAction = menu.addAction('Rafraichir')
       removeAction = menu.addAction('Supprimer ce trajet')
+      QtCore.QObject.connect(refreshAction, QtCore.SIGNAL("triggered()"), self.Refresh)
       QtCore.QObject.connect(removeAction, QtCore.SIGNAL("triggered()"), self.Remove)
       title.setMenu(menu)
       layoutTitle.addWidget(title)
@@ -136,7 +138,12 @@ class RideView(QtGui.QWidget):
       self.layout.addLayout( layoutTitle, 0, 1, 1, 3, Qt.AlignLeft|Qt.AlignVCenter )
 
    def Remove(self):
-      self.parent.RemoveView(self)
+      reply = QtGui.QMessageBox.question(None, 'Message',
+             "Supprimer le trajet '%s'?"%self.model.getTitle(),
+             QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+
+      if reply == QtGui.QMessageBox.Yes:
+         self.parent.RemoveView(self)
 
    def Animate(self, variant):
       self.progress.setFixedHeight(variant.toSize().height())
@@ -146,6 +153,10 @@ class RideView(QtGui.QWidget):
       if size.height()==0:
          self.progress.hide()
 
+   def Refresh(self):
+      self.Busy()
+      self.parent.model.RefreshDatas(self.model.id)
+
    def UpdateRides(self):
       DebugLog("RideView::UpdateRides")
       irow=2
