@@ -7,7 +7,8 @@ from PyQt4.QtCore import Qt
 from utils.DebugLog import DebugLog
 from model.TrainTrainModel import TrainTrainModel
 from view.RideView import RideView
-from view.Settings import SettingsDlg
+from view.SettingsDlg import SettingsDlg
+from view.AddRide import AddRideDlg
 
 class TrainTrainView(QtGui.QMainWindow):
 
@@ -31,7 +32,6 @@ class TrainTrainView(QtGui.QMainWindow):
          self.setMinimumSize(QtCore.QSize(480, 800))
          pass
 
-
       self.setWindowTitle('TrainTrain')
 
       self.model = TrainTrainModel()
@@ -52,7 +52,11 @@ class TrainTrainView(QtGui.QMainWindow):
       self.SetLoading(True)
 
    def Settings(self):
-      dlg = SettingsDlg(self.model.garesConf)
+      dlg = SettingsDlg()
+      dlg.exec_()
+
+   def AddRide(self):
+      dlg = AddRideDlg(self.model.garesConf)
       dlg.exec_()
       ride = dlg.added
       if ride:
@@ -81,12 +85,16 @@ class TrainTrainView(QtGui.QMainWindow):
 
       add = QtGui.QAction(u'Ajouter un trajet', self)
       add.setShortcut('Ctrl+A')
-      self.connect(add, QtCore.SIGNAL('triggered()'),self.Settings)
+      self.connect(add, QtCore.SIGNAL('triggered()'),self.AddRide)
 
-      update = QtGui.QAction(u'Rafraichir', self)
+      update = QtGui.QAction(u'Rafraîchir', self)
       update.setShortcut('Ctrl+R')
       self.connect(update, QtCore.SIGNAL('triggered()'), self.Update)
 
+      settings = QtGui.QAction(u'Paramètres', self)
+      settings.setShortcut('Ctrl+O')
+      self.connect(settings, QtCore.SIGNAL('triggered()'), self.Settings)
+
       about = QtGui.QAction(u'A propos...', self)
       self.connect(about, QtCore.SIGNAL('triggered()'), self.About)
 
@@ -94,6 +102,7 @@ class TrainTrainView(QtGui.QMainWindow):
       file = menubar.addMenu('&Options')
       file.addAction(add)
       file.addAction(update)
+      file.addAction(settings)
       file.addAction(about)
 
       self.scrollArea = QtGui.QScrollArea(self)#.centralWidget)
@@ -111,7 +120,7 @@ class TrainTrainView(QtGui.QMainWindow):
       self.tLayout.addLayout(self.vLayout)
       addButton = QtGui.QPushButton('Ajouter un trajet')
       self.tLayout.addWidget(addButton)
-      addButton.clicked.connect(self.Settings)
+      addButton.clicked.connect(self.AddRide)
       addButton.setDefault(True)
       addButton.setStyleSheet('background-color:#2684DB; color: #fff; margin: 5px; padding: 5px;')
 
